package reborncore.common.util;

import net.minecraft.inventory.IInventory;
import net.minecraft.item.ItemStack;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;
import net.minecraftforge.oredict.OreDictionary;

import java.util.ArrayList;
import java.util.List;

/**
 * Created by mark on 12/04/15.
 */
public class ItemUtils {

    public static boolean isItemEqual(final ItemStack a, final ItemStack b,
                                      final boolean matchDamage, final boolean matchNBT) {
        if (a == null || b == null)
            return false;
        if (a.func_77973_b() != b.func_77973_b())
            return false;
        if (matchNBT && !ItemStack.func_77970_a(a, b))
            return false;
        if (matchDamage && a.func_77981_g()) {
            if (isWildcard(a) || isWildcard(b))
                return true;
            if (a.func_77952_i() != b.func_77952_i())
                return false;
        }
        return true;
    }

    public static boolean isItemEqual(ItemStack a, ItemStack b,
                                      boolean matchDamage, boolean matchNBT, boolean useOreDic) {
        if (isItemEqual(a, b, matchDamage, matchNBT)) {
            return true;
        }
        if (a == null || b == null)
            return false;
        if (useOreDic) {
            for (int inta : OreDictionary.getOreIDs(a)) {
                for (int intb : OreDictionary.getOreIDs(b)) {
                    if (inta == intb) {
                        return true;
                    }
                }
            }
        }
        return false;
    }


    public static boolean isWildcard(ItemStack stack) {
        return isWildcard(stack.func_77952_i());
    }

    public static boolean isWildcard(int damage) {
        return damage == -1 || damage == OreDictionary.WILDCARD_VALUE;
    }

    public static void writeInvToNBT(IInventory inv, String tag,
                                     NBTTagCompound data) {
        NBTTagList list = new NBTTagList();
        for (byte slot = 0; slot < inv.func_70302_i_(); slot++) {
            ItemStack stack = inv.func_70301_a(slot);
            if (stack != null) {
                NBTTagCompound itemTag = new NBTTagCompound();
                itemTag.func_74774_a("Slot", slot);
                writeItemToNBT(stack, itemTag);
                list.func_74742_a(itemTag);
            }
        }
        data.func_74782_a(tag, list);
    }

    public static void readInvFromNBT(IInventory inv, String tag,
                                      NBTTagCompound data) {
        NBTTagList list = data.func_150295_c(tag, 10);
        for (byte entry = 0; entry < list.func_74745_c(); entry++) {
            NBTTagCompound itemTag = list.func_150305_b(entry);
            int slot = itemTag.func_74771_c("Slot");
            if (slot >= 0 && slot < inv.func_70302_i_()) {
                ItemStack stack = readItemFromNBT(itemTag);
                inv.func_70299_a(slot, stack);
            }
        }
    }

    public static void writeItemToNBT(ItemStack stack, NBTTagCompound data) {
        if (stack == null || stack.field_77994_a <= 0)
            return;
        if (stack.field_77994_a > 127)
            stack.field_77994_a = 127;
        stack.func_77955_b(data);
    }

    public static ItemStack readItemFromNBT(NBTTagCompound data) {
        return ItemStack.func_77949_a(data);
    }

    public static List<ItemStack> getStackWithAllOre(ItemStack stack) {
        if (stack == null) {
            return new ArrayList<ItemStack>();
        }
        ArrayList<ItemStack> list = new ArrayList<ItemStack>();
        for (int oreID : OreDictionary.getOreIDs(stack)) {
            for (ItemStack ore : OreDictionary.getOres(OreDictionary.getOreName(oreID))) {
                ItemStack newOre = ore.func_77946_l();
                newOre.field_77994_a = stack.field_77994_a;
                list.add(newOre);
            }
        }
        if (list.isEmpty()) {
            list.add(stack);
        }
        return list;
    }
}
